import os
def run():
    def command_run():
        clear = input("give your screen clearing command [cls or clear]: ")
        os.system(clear)
        print("Designed by Kanish Ravikumar")
        print("____________________________________")
        print(f"            {name}                 ")
        print("____________________________________")
        print("To exit type 'exit()'")
        while True:
            print(prefix+"[@]:")
            main=input("$ ")
            os.system(main)
            if main == "exit()":
                break
    name = input("Enter TERMINAL name: ")
    prefix = input("Enter your prefix: ")
    command_run()



from setuptools import setup


def readme():
    with open("README.md") as f:
        return f.read()


setup(
    name="cml_easy",
    version="0.1.1",
    description="Create a terminal command line with just 2 lines of code",
    long_description=readme(),
    long_description_content_type="text/markdown",
    classifiers=[
        "Development Status :: 4 - Beta",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Operating System :: OS Independent",
    ],
    url="https://github.com/dead-zone-termux",
    author="kanish",
    author_email="kanish.ravikumar@gmail.com",
    keywords="core",
    license="MIT",
    packages=["cml"],
    install_requires=[],
    include_package_data=True,
    zip_safe=False,
)